summaryrefslogtreecommitdiffstats
path: root/khtml/rendering/render_list.h
diff options
context:
space:
mode:
Diffstat (limited to 'khtml/rendering/render_list.h')
-rw-r--r--khtml/rendering/render_list.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/khtml/rendering/render_list.h b/khtml/rendering/render_list.h
index 84c7d0906..b70132671 100644
--- a/khtml/rendering/render_list.h
+++ b/khtml/rendering/render_list.h
@@ -58,7 +58,7 @@ public:
void setValue( long v ) { predefVal = v; }
- virtual void tqlayout( );
+ virtual void layout( );
virtual void detach( );
virtual void calcMinMaxWidth();
//virtual short marginLeft() const;
@@ -89,11 +89,11 @@ public:
virtual void setStyle(RenderStyle *style);
virtual const char *renderName() const { return "RenderListMarker"; }
// so the marker gets to tqlayout itself. Only needed for
// list-style-position: inside
virtual void paint(PaintInfo& i, int xoff, int yoff);
- virtual void tqlayout( );
+ virtual void layout( );
virtual void calcMinMaxWidth();
virtual short lineHeight( bool firstLine ) const;
@@ -123,7 +123,7 @@ protected:
};
// Implementation of list-item counter
-// ### should tqreplace most list-item specific code in renderObject::getCounter
+// ### should replace most list-item specific code in renderObject::getCounter
/*
class CounterListItem : public CounterNode
{
@@ -89,11 +89,11 @@ public:
virtual void setStyle(RenderStyle *style);
virtual const char *renderName() const { return "RenderListMarker"; }
- // so the marker gets to tqlayout itself. Only needed for
+ // so the marker gets to layout itself. Only needed for
// list-style-position: inside
virtual void paint(PaintInfo& i, int xoff, int yoff);